==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/Paste/ts/Paste_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Paste</name>
    <message>
        <location filename="../Paste.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>Rotación:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate pasted entities&lt;br&gt;by this angle</source>
        <translation>Girar las entidades&lt;br&gt;pegadas por este ángulo</translation>
    </message>
    <message>
        <location line="+97"/>
        <source>Scale:</source>
        <translation>Escala:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale pasted entities&lt;br&gt;by this factor</source>
        <translation>Escala de entidades&lt;br&gt;pegadas por este factor</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Flip pasted entities&lt;br&gt;horizontally</source>
        <translation>Voltear las entidades&lt;br&gt;pegado horizontal</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Flip pasted entities&lt;br&gt;vertically</source>
        <translation>Voltear las entidades&lt;br&gt;pegado verticalmente</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Paste all entities&lt;br&gt;to current layer&lt;br&gt;instead of original layer</source>
        <translation>Pegar todas las entidades&lt;br&gt;a la capa actual en&lt;br&gt;lugar de la capa original</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>To current layer</source>
        <translation>En la capa actual</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing layers&lt;br&gt;in drawing with&lt;br&gt;layers from clipboard</source>
        <translation>Sobrescribir las capas&lt;br&gt;existentes en el dibujo con&lt;br&gt;las capas desde el portapapeles</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite layers</source>
        <translation>Sobrescribir las capas</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing blocks&lt;br&gt;in drawing with&lt;br&gt;blocks from clipboard</source>
        <translation>Sobreescribir los bloques&lt;br&gt;existentes en la elaboración&lt;br&gt;de bloques desde el portapapeles</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite blocks</source>
        <translation>Sobreescribir los bloques</translation>
    </message>
    <message>
        <location filename="../Paste.js" line="+77"/>
        <source>Position</source>
        <translation>Posición</translation>
    </message>
    <message>
        <location filename="../PasteInit.js" line="+2"/>
        <source>&amp;Paste</source>
        <translation>&amp;Pegar</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/Paste/ts/Paste_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Paste</name>
    <message>
        <location filename="../Paste.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>Rotación:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate pasted entities&lt;br&gt;by this angle</source>
        <translation>Girar las entidades&lt;br&gt;pegadas por este ángulo</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Scale:</source>
        <translation>Escala:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale pasted entities&lt;br&gt;by this factor</source>
        <translation>Escala de entidades&lt;br&gt;pegadas por este factor</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Flip pasted entities&lt;br&gt;horizontally</source>
        <translation>Voltear las entidades&lt;br&gt;pegado horizontal</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Flip pasted entities&lt;br&gt;vertically</source>
        <translation>Voltear las entidades&lt;br&gt;pegado verticalmente</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Paste all entities&lt;br&gt;to current layer&lt;br&gt;instead of original layer</source>
        <translation>Pegar todas las entidades&lt;br&gt;a la capa actual en&lt;br&gt;lugar de la capa original</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>To current layer</source>
        <translation>En la capa actual</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing layers&lt;br&gt;in drawing with&lt;br&gt;layers from clipboard</source>
        <translation>Sobrescribir las capas&lt;br&gt;existentes en el dibujo con&lt;br&gt;las capas desde el portapapeles</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite layers</source>
        <translation>Sobrescribir las capas</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing blocks&lt;br&gt;in drawing with&lt;br&gt;blocks from clipboard</source>
        <translation>Sobreescribir los bloques&lt;br&gt;existentes en la elaboración&lt;br&gt;de bloques desde el portapapeles</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite blocks</source>
        <translation>Sobreescribir los bloques</translation>
    </message>
    <message>
        <location filename="../Paste.js" line="+52"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Position</source>
        <translation>Posición</translation>
    </message>
    <message>
        <location filename="../PasteInit.js" line="+2"/>
        <source>&amp;Paste</source>
        <translation>&amp;Pegar</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Reset to defaults every time tool is used</source>
        <translation>Restablecer los valores predeterminados cada vez que se utiliza la herramienta</translation>
    </message>
</context>
</TS>
